let app
let submitBtn
let paymentErr
let wooshpay
let elements
let client_secret

const url = window.location.pathname
const search = window.location.search
const params = new URLSearchParams(search)

client_secret = params.get('client_secret') || null

const publishableKey = 'publishableKey'

// Create your wooshpay
wooshpay = Wooshpay(
    publishableKey,
    {
      locale: 'en',
    }
)

// Get payment container
app = document.getElementById('payment-app')
// Get button container
submitBtn = document.getElementById('submit-btn')
// Get error message container
paymentErr = document.getElementById('payment-err')
// Show  message
const showMessage = (type) => {
  paymentErr.innerHTML = type
}
// Reset button state
const Remove=()=> {
  submitBtn.innerHTML = 'Pay now'
  submitBtn.removeAttribute('disabled')
  setTimeout(()=>{
    paymentErr.innerHTML =''
  },5000)
}
// Check payment status
const checkStatus = async () => {
  if (!!client_secret) {
    let res = await wooshpay.retrievePaymentIntent(client_secret,{auth:{
      username:publishableKey,
      password:''
    }})
    const {data} = res
   
    if (data?.status === 'succeeded') {
      // If the payment is successful, the processing after successful completion will be based on your business.
      showMessage('succeeded')
    } else {
      // Get the current failure reason for this order
      if (!!data?.last_payment_error) {
       const {message} = data.last_payment_error 
       showMessage(message)
      }
    }
  }
}

const initialize = async()=> {

  // Create your client secret
  const response = await fetch(
    '/create-payment-intent',
    {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
    }
  )



  const { client_secret } = await response.json()
  //  Set up Wooshpay.js and Elements to use in checkout form, passing the client secret obtained in a previous step
  elements = wooshpay.elements({
    clientSecret: client_secret,
    appearance: {
      bankIcons: [
        'https://jstest.wooshpay.com/v1/public/visa-729c05c240c4bdb47b03ac81d9945bfe.svg',
        'https://jstest.wooshpay.com/v1/public/mastercard-4d8844094130711885b5e41b28c9848f.svg'
      ],
    },
  })
  // Create and mount the Payment Element
  elements.create('payment', {   paymentMethodOrder: ['alipay', 'dana', 'wechat_pay', 'unionpay', 'card'],billingDetails: 'auto' })
  elements.mount(app)

  // watch user confirm paymentIntent

}

// Payment event
const onConfirmPay = async (e) => {
  // Prevent repeated submissions and add a loading state to your button
  e.preventDefault()
  paymentErr.innerHTML = ''
  submitBtn.innerHTML = '<div class="subloading"></div>'
  submitBtn.setAttribute('disabled', true)
  // Pre-validation prevents your execution process from being in the wrong order
  if (
    !(
      elements &&
      elements.clientSecret &&
      elements.wooshpay &&
      elements.wooshpay.publishableKey
    )
  ) {
    paymentErr.innerHTML = 'clientSecret or publishableKey is required'
    Remove()
  }
  // Start your payment
  try {
    const response = await wooshpay.confirmPayment({
      elements,
      confirmParams: {
        shipping: {},
        return_url: url + '?client_secret=' + elements.clientSecret,
        redirect: 'always',
        payment_method_data: {},
      },
    })
   
    //  payment successful
    if ( response.status === "succeeded" || response.status == "requires_capture") {
      // Successful processing based on your business
      paymentErr.innerHTML = 'success'
      return
    } 

    // Reset payment button
    Remove()

    // Error reports are divided into interface exceptions and business logic processing failures. You can handle them accordingly according to your business logic.
    // Interface exception eg.api_error/card_error/idempotency_error/invalid_request_error...
    if (!!response.type) {
      const errmessage = response.type?.split('_')[1] || null
      if (errmessage == 'error') {
        paymentErr.innerHTML = response?.message
        return
      }
    } else if (response?.code) {
      paymentErr.innerHTML = response?.message || response?.code
      return
    }

     // Business logic processing failed
    if (!!response.last_payment_error && response.status=='requires_payment_method') {
      const flag = response.last_payment_error || {}
      paymentErr.innerHTML = flag?.message
      return
    }
    

  } catch (e) {
    console.log(e,'e');
    Remove()
  } 
}

initialize()

checkStatus()

app.addEventListener('submit', onConfirmPay)
